@@ -170,7 +170,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.32'
+__version__ = '0.1.33'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -250,7 +250,7 @@ def flow_path_items_from_text(text: str) -> Tuple[str, LiszNode]:
     elif text.startswith('['):
         node_lit = text
     else:
-        parts = text.split("\n", maxsplit=1)
+        parts = norm_line_sep(text).split("\n", maxsplit=1)
         if len(parts) == 2 and parts[1].startswith(('[', '{')):
             flow_path_text = parts[0]
             node_lit = parts[1] if parts[1][0] == '[' else "[" + parts[1] + "]"
@@ -265,27 +265,6 @@ def flow_path_items_from_text(text: str) -> Tuple[str, LiszNode]:
     return flow_path_text, node
 
 
-"""
-
-        item = ast.literal_eval(text)
-        print("=== sent item", item)
-        self.add_item(item)
-    elif "\n" in text:
-        print("=== sent flow path and node", text)
-        flow_path_text, node_literal = text.split("\n", maxsplit=1)
-        flow_path = self.flow_path_from_text(flow_path_text, skip_check=True)
-        print("    resulting flow_path:", flow_path)
-        node = ast.literal_eval(node_literal)
-        print("    resulting node:", node)
-        node_to_add_to = self.flow_path_node(flow_path, create=True)
-        self.add_items(node, node_to_add_to=node_to_add_to)
-    else:
-        item_id = text
-        print("=== sent item id", item_id)
-        self.add_item(dict(id=item_id))
-"""
-
-
 def item_sel_filter(item: LiszItem) -> bool:
     """ callable for to filter selected LiszItems.
 
@@ -316,31 +295,6 @@ def item_unsel_filter(item: LiszItem) -> bool:
     return item.get('sel', 0) == 0
 
 
-def node_from_literal(lit: str) -> LiszNode:
-    """ parse passed string for to integrate/add them into the current displayed node or item.
-
-    :param lit:                 item/node data in string representation format.
-    :return:                    LiszNode list of parsed LiszItem items.
-    """
-    if lit.startswith('['):
-        try:
-            node = ast.literal_eval(lit)
-        except (SyntaxError, ValueError):
-            node = list()
-
-    elif lit.startswith('{'):
-        try:
-            node = [ast.literal_eval(lit)]
-        except (SyntaxError, ValueError):
-            node = list()
-
-    else:
-        node = [dict(id=correct_item_id(item_id)) for item_id in norm_line_sep(lit).split('\n')
-                if correct_item_id(item_id)]
-
-    return node
-
-
 class LiszDataMixin(ABC):
     """ lisz data model - independent from used GUI framework. """
     root_node: LiszNode             #: root of lisz data structure
@@ -633,7 +587,7 @@ class LiszDataMixin(ABC):
         return flow_path
 
     def flow_path_node(self, flow_path: List[str] = None, create: bool = False) -> LiszNode:
-        """ determine the node specified by the passed flow path.
+        """ determine the node specified by the passed flow path, optionally create missing nodes of the flow path.
 
         :param flow_path:       flow path list.
         :param create:          pass True to create missing nodes.
@@ -776,7 +730,7 @@ class LiszDataMixin(ABC):
             return (node_name, list(), file_path,
                     f"import file is bigger than {IMPORT_NODE_MAX_FILE_LEN} bytes ({file_len})")
 
-        node = node_from_literal(file_content)
+        _, node = flow_path_items_from_text(file_content)   # ignore optional flow path given in 1st line
         if not node:
             return node_name, list(), file_path, "invalid file content or empty file"
 
